aboutsummaryrefslogtreecommitdiff
path: root/libbb
diff options
context:
space:
mode:
authorDenys Vlasenko <vda.linux@googlemail.com>2014-05-02 17:15:58 +0200
committerDenys Vlasenko <vda.linux@googlemail.com>2014-05-02 17:15:58 +0200
commite765b5ac349a8f9305e52b3ab2c3ac78c17bf283 (patch)
tree2dec8a3b34450b7088ae7c3a4b374e953c0a4a73 /libbb
parent15a357e5962634c94ee322fee4da897312090a89 (diff)
downloadbusybox-e765b5ac349a8f9305e52b3ab2c3ac78c17bf283.tar.gz
libbb: rename execable -> executable. No code changes
English speakers complained that it sounded awfully broken. Signed-off-by: Denys Vlasenko <vda.linux@googlemail.com>
Diffstat (limited to 'libbb')
-rw-r--r--libbb/Kbuild.src2
-rw-r--r--libbb/executable.c (renamed from libbb/execable.c)12
2 files changed, 7 insertions, 7 deletions
diff --git a/libbb/Kbuild.src b/libbb/Kbuild.src
index a6468f171..6578d1171 100644
--- a/libbb/Kbuild.src
+++ b/libbb/Kbuild.src
@@ -30,7 +30,7 @@ lib-y += crc32.o
lib-y += default_error_retval.o
lib-y += device_open.o
lib-y += dump.o
-lib-y += execable.o
+lib-y += executable.o
lib-y += fclose_nonstdin.o
lib-y += fflush_stdout_and_exit.o
lib-y += fgets_str.o
diff --git a/libbb/execable.c b/libbb/executable.c
index a3caea6f9..85ecc3e6c 100644
--- a/libbb/execable.c
+++ b/libbb/executable.c
@@ -13,7 +13,7 @@
* return 1 if found;
* return 0 otherwise;
*/
-int FAST_FUNC execable_file(const char *name)
+int FAST_FUNC file_is_executable(const char *name)
{
struct stat s;
return (!access(name, X_OK) && !stat(name, &s) && S_ISREG(s.st_mode));
@@ -23,12 +23,12 @@ int FAST_FUNC execable_file(const char *name)
* return allocated string containing full path if found;
* PATHp points to the component after the one where it was found
* (or NULL),
* you may call find_execable again with this PATHp to continue
* (if it's not NULL).
* return NULL otherwise; (PATHp is undefined)
* in all cases (*PATHp) contents will be trashed (s/:/NUL/).
*/
-char* FAST_FUNC find_execable(const char *filename, char **PATHp)
+char* FAST_FUNC find_executable(const char *filename, char **PATHp)
{
/* About empty components in $PATH:
* http://pubs.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap08.html
@@ -49,7 +49,7 @@ char* FAST_FUNC find_execable(const char *filename, char **PATHp)
p[0] ? p : ".", /* handle "::" case */
filename
);
- if (execable_file(p)) {
+ if (file_is_executable(p)) {
*PATHp = n;
return p;
}
@@ -63,11 +63,11 @@ char* FAST_FUNC find_execable(const char *filename, char **PATHp)
* return 1 if found;
* return 0 otherwise;
*/
-int FAST_FUNC exists_execable(const char *filename)
+int FAST_FUNC executable_exists(const char *filename)
{
char *path = xstrdup(getenv("PATH"));
char *tmp = path;
- char *ret = find_execable(filename, &tmp);
+ char *ret = find_executable(filename, &tmp);
free(path);
free(ret);
return ret != NULL;
@@ -23,12 +23,12 @@ int FAST_FUNC execable_file(const char *name)
* PATHp points to the component after the one where it was found
* (or NULL),
- * you may call find_execable again with this PATHp to continue
+ * you may call find_executable again with this PATHp to continue
* (if it's not NULL).
* return NULL otherwise; (PATHp is undefined)